@@ -64,9 +64,9 @@ class Client(object):
 
     # wrappers
     def _get_csv_wrapper(self, absolute_path, encoding='utf-8'):
-        return self.workspace.file.get_csv_wrapper(absolute_path, encoding='utf-8')
+        return self.workspace.file.get_csv_wrapper(absolute_path, encoding=encoding)
     def _get_json_wrapper(self, absolute_path, encoding='utf-8'):
-        return self.workspace.file.get_json_wrapper(absolute_path, encoding='utf-8')
+        return self.workspace.file.get_json_wrapper(absolute_path, encoding=encoding)
     def _get_image_wrapper(self, absolute_path):
         return self.workspace.file.get_image_wrapper(absolute_path)
     # csv
