@@ -68,9 +68,9 @@ class File(object):
     def get_content(self, absolutePath):
         r = self._get(absolutePath)
         return r.content
-    def get_text(self, absolutePath):
+    def get_text(self, absolutePath, encoding='utf-8'):
         r = self._get(absolutePath)
-        r.encoding = 'utf-8'
+        r.encoding = encoding
         return r.text
     def get_csv_wrapper(self, absolutePath, encoding='utf-8'):
         content = self.get_content(absolutePath)
